@@ -52,9 +52,8 @@ OC.L10N.register(
     "The file could not be converted." : "No s'ha pogut convertir el fitxer.",
     "Could not get relative path to converted file" : "No s'ha pogut obtenir el camí relatiu al fitxer convertit",
     "Favorite files" : "Fitxers preferits",
-    "No favorites" : "No hi ha favorits",
+    "No favorites" : "No hi ha preferits",
     "More favorites" : "Més preferits",
-    "Upload (max. %s)" : "Puja (màx. %s)",
     "Accept" : "Accepta",
     "Reject" : "Rebutja",
     "Incoming ownership transfer from {user}" : "{user} us ha enviat una transferència de propietat",
@@ -70,9 +69,9 @@ OC.L10N.register(
     "in %s" : "%s",
     "Transferred from %1$s on %2$s" : "S'ha transferit de %1$s a %2$s",
     "Files compatibility" : "Compatibilitat de fitxers",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet restringir els noms de fitxers per garantir que els fitxers es puguin sincronitzar amb tots els clients. De manera predeterminada, es permeten tots els noms de fitxer vàlids a POSIX (per exemple, Linux o macOS).",
-    "Enforce Windows compatibility" : "Impulsar la compatibilitat amb Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Això bloquejarà els noms de fitxer no vàlids als sistemes Windows, com ara l'ús de noms reservats o caràcters especials. Però això no farà complir la compatibilitat de la distinció entre majúscules i minúscules.",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet restringir els noms de fitxers per garantir que els fitxers es puguin sincronitzar amb tots els clients. Per defecte es permeten tots els noms de fitxer vàlids a POSIX (per exemple, Linux o macOS).",
+    "Enforce Windows compatibility" : "Força la compatibilitat amb Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Això bloquejarà els noms de fitxer no vàlids als sistemes Windows, com ara l'ús de noms reservats o caràcters especials. Però això no força la compatibilitat de la distinció entre majúscules i minúscules.",
     "File Management" : "Gestió de fitxers",
     "Home" : "Inici",
     "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
@@ -95,6 +94,7 @@ OC.L10N.register(
     "Invalid filename." : "Nom de fitxer no vàlid.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "S'ha canviat el nom de «{oldName}» a «{newName}»",
     "Rename file" : "Canvia el nom del fitxer",
+    "Folder" : "Carpeta",
     "Pending" : "Pendent",
     "Unknown date" : "Data desconeguda",
     "Clear filter" : "Esborra el filtre",
@@ -106,6 +106,7 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Canvia la selecció per a tots els fitxers i carpetes",
     "Name" : "Nom",
     "Size" : "Mida",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ha fallat en alguns elements",
     "\"{displayName}\" batch action executed successfully" : "L'acció per lots «{displayName}» s'ha executat correctament",
     "\"{displayName}\" action failed" : "S'ha produït un error en l'acció «{displayName}»",
     "Actions" : "Accions",
@@ -128,6 +129,7 @@ OC.L10N.register(
     "This name is already in use." : "Aquest nom ja s'utilitza.",
     "Create" : "Crea",
     "Fill template fields" : "Ompliu els camps de la plantilla",
+    "Submitting fields …" : "S'estan enviant camps …",
     "Submit" : "Envia",
     "Choose a file or folder to transfer" : "Trieu el fitxer o carpeta que voleu transferir",
     "Transfer" : "Transfereix",
@@ -140,11 +142,15 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Tria el fitxer o carpeta que voleu transferir",
     "Change" : "Canvia",
     "New owner" : "Propietari nou",
-    "Remove extension" : "Elimina l'extensió",
+    "Keep {old}" : "Mantenir {old}",
+    "Keep without extension" : "Mantenir sense extensió",
+    "Use {new}" : "Utilitza {new}",
+    "Remove extension" : "Suprimeix l'extensió",
     "Change file extension" : "Canvia l'extensió del fitxer",
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Canviar l'extensió del fitxer de \"{old}\" a \"{new}\" pot fer que el fitxer sigui il·legible.",
-    "Removing the file extension \"{old}\" may render the file unreadable." : "Eliminar l'extensió de fitxer \"{old}\" pot fer que el fitxer sigui il·legible.",
-    "Adding the file extension \"{new}\" may render the file unreadable." : "Afegir l'extensió de fitxer \"{new}\" pot fer que el fitxer sigui il·legible.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Suprimeix l'extensió de fitxer \"{old}\" pot fer que el fitxer sigui il·legible.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Afegir l'extensió del fitxer \"{new}\" pot fer que el fitxer sigui il·legible.",
+    "Do not show this dialog again." : "No torneu a mostrar aquest diàleg.",
     "Select file or folder to link to" : "Seleccioneu el fitxer o la carpeta que voleu enllaçar",
     "Choose {file}" : "Tria {file}",
     "Share" : "Comparteix",
@@ -152,6 +158,7 @@ OC.L10N.register(
     "Shared" : "S'ha compartit",
     "Switch to list view" : "Canvia a la visualització de llista",
     "Switch to grid view" : "Canvia a la visualització de quadrícula",
+    "The file could not be found" : "No s'ha pogut trobar el fitxer",
     "Upload was cancelled by user" : "L'usuari ha cancel·lat la pujada",
     "Not enough free space" : "No hi ha prou espai lliure",
     "Operation is blocked by access control" : "L'operació està blocada pel control d'accés",
@@ -164,6 +171,7 @@ OC.L10N.register(
     "No files in here" : "No hi ha cap fitxer aquí",
     "Upload some content or sync with your devices!" : "Pugeu contingut o sincronitzeu els vostres dispositius!",
     "Go back" : "Torna",
+    "Filter file names …" : "Filtra els noms dels fitxers …",
     "Views" : "Vistes",
     "Files settings" : "Paràmetres de Fitxers",
     "Your files" : "Els vostres fitxers",
@@ -184,13 +192,16 @@ OC.L10N.register(
     "Copy to clipboard" : "Copia-ho al porta-retalls",
     "Use this address to access your Files via WebDAV" : "Utilitzeu aquesta adreça per a accedir als vostres fitxers mitjançant WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si heu habilitat l'autenticació de doble factor, podeu crear i utilitzar una nova contrasenya d'aplicació fent clic aquí.",
+    "Warnings" : "Advertiments",
+    "Prevent warning dialogs from open or reenable them." : "Eviteu que s'obrin els diàlegs d'advertència o torneu-los a habilitar.",
+    "Show a warning dialog when changing a file extension." : "Mostra un diàleg d'avís quan es canvia una extensió de fitxer.",
     "Keyboard shortcuts" : "Dreceres de teclat",
     "Speed up your Files experience with these quick shortcuts." : "Accelereu l'experiència Fitxers amb aquestes dreceres ràpides.",
     "Open the actions menu for a file" : "Obre el menú d'accions per un fitxer",
     "Rename a file" : "Canvia el nom del fitxer",
     "Delete a file" : "Suprimeix el fitxer",
-    "Favorite or remove a file from favorites" : "Marca com a preferit o elimina un fitxer dels preferits",
-    "Manage tags for a file" : "Gestioneu les etiquetes d'un fitxer",
+    "Favorite or remove a file from favorites" : "Marca com a preferit o suprimeix un fitxer dels preferits",
+    "Manage tags for a file" : "Administra les etiquetes d'un fitxer",
     "Selection" : "Selecció",
     "Select all files" : "Seleccioneu tots els fitxers",
     "Deselect all files" : "Desseleccioneu tots els fitxers",
@@ -203,7 +214,7 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Navegueu fins al fitxer de l'esquerra (en mode de quadrícula)",
     "Navigate to the file on the right (in grid mode)" : "Navegueu fins al fitxer de la dreta (en mode de quadrícula)",
     "View" : "Visualització",
-    "Toggle the grid view" : "Canvia la vista de la quadrícula",
+    "Toggle the grid view" : "Commuta la vista de la quadrícula",
     "Open the sidebar for a file" : "Obriu la barra lateral d'un fitxer",
     "Show those shortcuts" : "Mostra aquestes dreceres",
     "You" : "Vós",
@@ -220,11 +231,15 @@ OC.L10N.register(
     "Creating file" : "S'està creant el fitxer",
     "Save as {displayName}" : "Desa com a {displayName}",
     "Save as …" : "Anomena i desa …",
+    "Converting files …" : "Convertint fitxers …",
     "Failed to convert files: {message}" : "No s'han pogut convertir els fitxers: {message}",
     "All files failed to be converted" : "No s'han pogut convertir tots els fitxers",
     "One file could not be converted: {message}" : "No s'ha pogut convertir un fitxer: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["No s'ha pogut convertir un fitxer","No s’han pogut convertir %n fitxers"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Un fitxer s'ha convertit correctament","%n fitxers s'han convertit correctament"],
     "Files successfully converted" : "Els fitxers s'han convertit correctament",
     "Failed to convert files" : "No s'han pogut convertir els fitxers",
+    "Converting file …" : "S'està convertint el fitxer …",
     "File successfully converted" : "El fitxer s'ha convertit correctament",
     "Failed to convert file: {message}" : "No s'ha pogut convertir el fitxer: {message}",
     "Failed to convert file" : "No s'ha pogut convertir el fitxer",
@@ -264,11 +279,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "S'ha cancel·lat l'operació de desplaçament o còpia",
     "Open folder {displayName}" : "Obre la carpeta {displayName}",
     "Open in Files" : "Obre a Fitxers",
+    "Open locally" : "Obre en local",
+    "Failed to redirect to client" : "No s'ha pogut redirigir al client",
     "Open file locally" : "Obre el fitxer en local",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Ara s'hauria d'obrir el fitxer al dispositiu. Si no és així, comproveu que teniu instal·lada l'aplicació d'escriptori.",
     "Retry and close" : "Torna-ho a provar i tanca",
-    "Failed to redirect to client" : "No s'ha pogut redirigir al client",
-    "Open locally" : "Obre en local",
+    "Open online" : "Obre en línia",
     "Rename" : "Canvia el nom",
     "Open details" : "Obre els detalls",
     "View in folder" : "Visualitza-ho en la carpeta",
@@ -283,7 +299,7 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Carpetes",
     "Audio" : "Àudio",
-    "Photos and images" : "Fotos i imatges",
+    "Photos and images" : "Fotografies i imatges",
     "Videos" : "Vídeos",
     "New folder creation cancelled" : "S'ha cancel·lat la creació de carpetes noves",
     "Created new folder \"{name}\"" : "S'ha creat la carpeta nova «{name}»",
@@ -310,14 +326,11 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Aquesta carpeta no està disponible. Consulteu els registres o contacteu amb l'administrador",
     "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
     "Unexpected error: {error}" : "Error inesperat: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fitxer","{fileCount} fitxers"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fitxer i {folderCount} carpeta","1 fitxer i {folderCount} carpetes"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fitxer i 1 carpeta","{fileCount} fitxers i 1 carpeta"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxers i {folderCount} carpetes",
+    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
+    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
     "Filename must not be empty." : "El nom del fitxer no ha d'estar buit.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no es permet dins d'un nom de fitxer.",
-    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" és un nom reservat i no es permet per als noms de fitxer.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no és permès dins d'un nom de fitxer.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" és un nom reservat i no és permès per als noms de fitxer.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" no és un tipus de fitxer permès.",
     "Filenames must not end with \"{extension}\"." : "Els noms de fitxer no han d'acabar amb \"{extension}\".",
     "List of favorite files and folders." : "Llista de fitxers i carpetes preferits.",
@@ -388,8 +401,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "S'ha produït un error en suprimir el fitxer «{fileName}».",
     "No search results in other folders for {tag}{filter}{endtag}" : "No hi ha cap resultat de cerca en altres carpetes per a {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Introduïu més de dos caràcters per a cercar en altres carpetes",
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
-    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
     "{dirs} and {files}" : "{dirs} i {files}",
     "_including %n hidden_::_including %n hidden_" : ["incloent-hi %n element ocult","incloent-hi %n elements ocults"],
     "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
@@ -415,28 +426,23 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per a les persones que tenen accés a aquest fitxer o carpeta)",
     "Path" : "Camí",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "En els preferits",
+    "Favored" : "Afavorit",
+    "Favor" : "Afavorir",
     "Copy direct link (only works for people who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per a les persones que tinguin accés a aquest fitxer o carpeta)",
     "Upload file" : "Puja un fitxer",
-    "Not favorited" : "No s'inclou en els preferits",
+    "Not favored" : "No afavorit",
     "An error occurred while trying to update the tags" : "S'ha produït un error en intentar actualitzar les etiquetes",
-    "Storage informations" : "Informació d'emmagatzematge",
-    "Choose file" : "Tria el fitxer",
-    "Go to the previous folder" : "Torna a la carpeta anterior",
-    "Open the files app settings" : "Obre els paràmetres de l'aplicació Fitxers",
-    "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de preferit del fitxer",
-    "Edit file locally" : "Edita el fitxer localment",
-    "Edit online" : "Edita en remot",
-    "Create new templates folder" : "Crea la carpeta de plantilles",
-    "List of favorites files and folders." : "Llista de fitxers i carpetes preferits.",
+    "Upload (max. %s)" : "Puja (màx. %s)",
+    "Submitting fields…" : "S'estan enviant camps…",
+    "Filter filenames…" : "Filtra els noms de fitxer…",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fitxer","{fileCount} fitxers"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fitxer i {folderCount} carpeta","1 fitxer i {folderCount} carpetes"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fitxer i 1 carpeta","{fileCount} fitxers i 1 carpeta"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxers i {folderCount} carpetes",
     "Personal Files" : "FItxers personals",
     "Text file" : "Fitxer de text",
     "New text file.txt" : "Fitxer de text nou.txt",
-    "Favored" : "Afavorit",
-    "Favor" : "Afavorir",
-    "Not favored" : "No afavorit",
-    "Submitting fields…" : "S'estan enviant camps…",
-    "Filter filenames…" : "Filtra els noms de fitxer…",
     "{count} files could not be converted" : "No s'han pogut convertir {count} fitxers",
     "{count} files successfully converted" : "{count} fitxers convertits correctament"
 },
