@@ -54,7 +54,6 @@ OC.L10N.register(
     "Favorite files" : "Comhaid is fearr leat",
     "No favorites" : "Gan aon cheanáin",
     "More favorites" : "Gan aon cheanáin",
-    "Upload (max. %s)" : "Uaslódáil (%s ar a mhéad)",
     "Accept" : "Glac",
     "Reject" : "Diúltaigh",
     "Incoming ownership transfer from {user}" : "Aistriú úinéireachta isteach ó {user}",
@@ -71,6 +70,8 @@ OC.L10N.register(
     "Transferred from %1$s on %2$s" : "Aistrithe ó %1$s ar %2$s",
     "Files compatibility" : "Comhoiriúnacht comhaid",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ceadaigh comhaid a shrianadh lena chinntiú gur féidir comhaid a shioncronú le gach cliant. De réir réamhshocraithe ceadaítear gach comhadainm atá bailí ar POSIX (m.sh. Linux nó macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Is féidir comhaid a aistriú go huathoibríoch freisin tar éis an socrú seo a chumasú, féach ar an doiciméadú faoin ordú occ.",
     "Enforce Windows compatibility" : "Comhoiriúnacht Windows a fhorfheidhmiú",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cuirfidh sé seo bac ar ainmneacha comhaid nach bhfuil bailí ar chórais Windows, ar nós ainmneacha forchoimeádta nó carachtair speisialta a úsáid. Ach ní chuirfidh sé seo i bhfeidhm comhoiriúnacht íogaireacht cáis.",
     "File Management" : "Bainistíocht Comhad",
@@ -95,6 +96,12 @@ OC.L10N.register(
     "Invalid filename." : "Ainm comhaid neamhbhailí.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Athainmnithe \"{oldName}\" go \"{newName}\"",
     "Rename file" : "Athainmnigh an comhad",
+    "Folder" : "Fillteán",
+    "Unknown file type" : "Cineál comhaid anaithnid",
+    "{ext} image" : "íomhá {ext}",
+    "{ext} video" : "físeán {ext}",
+    "{ext} audio" : "fuaim {ext}",
+    "{ext} text" : "téacs {ext}",
     "Pending" : "Ar feitheamh",
     "Unknown date" : "Dáta anaithnid",
     "Clear filter" : "Glan an scagaire",
@@ -105,6 +112,7 @@ OC.L10N.register(
     "Total rows summary" : "Achoimre ar na sraitheanna iomlána",
     "Toggle selection for all files and folders" : "Scoránaigh an roghnúchán do gach comhad agus fillteán",
     "Name" : "Ainm",
+    "File type" : "Cineál comhaid",
     "Size" : "Méid",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" theip ar roinnt gnéithe",
     "\"{displayName}\" batch action executed successfully" : "D'éirigh le beart baisce \"{displayName}\" a rith",
@@ -183,6 +191,7 @@ OC.L10N.register(
     "Sort favorites first" : "Sórtáil na cinn is ansa leat ar dtús",
     "Sort folders before files" : "Sórtáil fillteáin roimh chomhaid",
     "Show hidden files" : "Taispeáin comhaid i bhfolach",
+    "Show file type column" : "Taispeáin colún cineál comhaid",
     "Crop image previews" : "Réamhamhairc íomhá barr",
     "Enable the grid view" : "Cumasaigh an radharc greille",
     "Enable folder tree" : "Cumasaigh crann fillteáin",
@@ -279,12 +288,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Oibríocht aistrithe nó cóipeála curtha ar ceal",
     "Open folder {displayName}" : "Oscail fillteán {displayName}",
     "Open in Files" : "Oscail i Comhaid",
+    "Open locally" : "Oscail go háitiúil",
+    "Failed to redirect to client" : "Theip ar atreorú chuig an gcliant",
     "Open file locally" : "Oscail comhad go háitiúil",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Ba cheart an comhad a oscailt anois ar do ghléas. Mura ndéanann sé, seiceáil le do thoil go bhfuil an aip deisce suiteáilte agat.",
     "Retry and close" : "Bain triail eile as agus dún",
     "Open online" : "Oscail ar líne",
-    "Failed to redirect to client" : "Theip ar atreorú chuig an gcliant",
-    "Open locally" : "Oscail go háitiúil",
     "Rename" : "Athainmnigh",
     "Open details" : "Sonraí oscailte",
     "View in folder" : "Amharc san fhillteán",
@@ -326,12 +335,9 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
     "Storage is temporarily not available" : "Níl stóráil ar fáil go sealadach",
     "Unexpected error: {error}" : "Earráid gan choinne: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} fillteán","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} comhad","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 chomhad agus {folderCount} fillteán","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} comhad agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán"],
-    "{fileCount} files and {folderCount} folders" : "comhaid {fileCount} agus fillteáin {folderCount}",
-    "_(%n hidden)_::_ (%n hidden)_" : ["(%n i bhfolach)","(%n i bhfolach)","(%n i bhfolach)","(%n i bhfolach)","(%n i bhfolach)"],
+    "_%n file_::_%n files_" : ["%n comhad","%n comhaid","%n comhaid","%n comhaid","%n comhaid"],
+    "_%n folder_::_%n folders_" : ["%n fillteán","%n fillteáin","%n fillteáin","%n fillteáin","%n fillteáin"],
+    "_%n hidden_::_%n hidden_" : ["%n i bhfolach","%n i bhfolach","%n i bhfolach","%n i bhfolach","%n i bhfolach"],
     "Filename must not be empty." : "Ní ceadmhach ainm an chomhaid a bheith folamh.",
     "\"{char}\" is not allowed inside a filename." : "Ní cheadaítear \"{char}\" taobh istigh d'ainm comhaid.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "Is ainm forchoimeádta é \"{segment}\" agus ní cheadaítear é d'ainmneacha comhaid.",
@@ -405,8 +411,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Earráid agus comhad \"{fileName}\" á scriosadh.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Níl aon toradh cuardaigh i bhfillteáin eile le haghaidh {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Cuir isteach níos mó ná dhá charachtar chun cuardach a dhéanamh i bhfillteáin eile",
-    "_%n folder_::_%n folders_" : ["%n fillteán","%n fillteáin","%n fillteáin","%n fillteáin","%n fillteáin"],
-    "_%n file_::_%n files_" : ["%n comhad","%n comhaid","%n comhaid","%n comhaid","%n comhaid"],
     "{dirs} and {files}" : "{dirs} agus {files}",
     "_including %n hidden_::_including %n hidden_" : ["lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach","lena n-áirítear %n i bhfolach"],
     "You do not have permission to upload or create files here" : "Níl cead agat comhaid a uaslódáil nó a chruthú anseo",
@@ -432,29 +436,26 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Cóipeáladh nasc díreach (oibreacha do dhaoine a bhfuil rochtain acu ar an gcomhad/fillteán seo amháin)",
     "Path" : "Cosán",
     "_%n byte_::_%n bytes_" : ["%n beart ","%n bearta ","%n bearta","%n bearta","%n bearta"],
-    "Favorited" : "Is fearr leat",
+    "Favored" : "B'fhearr leis",
+    "Favor" : "Fabhar",
     "Copy direct link (only works for people who have access to this file/folder)" : "Cóipeáil nasc díreach (ní oibríonn ach do dhaoine a bhfuil rochtain acu ar an gcomhad/fillteán seo)",
     "Upload file" : "Uaslódáil comhad",
-    "Not favorited" : "Ní fearr leat",
+    "Not favored" : "Ní bail ar fónamh orthu",
     "An error occurred while trying to update the tags" : "Tharla earráid agus iarracht á déanamh na clibeanna a nuashonrú",
-    "You don't have permission to upload or create files here." : "Níl cead agat comhaid a uaslódáil nó a chruthú anseo.",
-    "Storage informations" : "Faisnéis stórála",
-    "Choose file" : "Roghnaigh comhad",
-    "Go to the previous folder" : "Téigh go dtí an fillteán roimhe seo",
-    "Open the files app settings" : "Oscail na socruithe aip comhaid",
-    "Unable to change the favourite state of the file" : "Ní féidir staid an chomhaid is fearr leat a athrú",
-    "Edit file locally" : "Cuir an comhad in eagar go háitiúil",
-    "Edit online" : "Cuir in eagar ar líne",
-    "Create new templates folder" : "Cruthaigh fillteán teimpléid nua",
-    "List of favorites files and folders." : "Liosta de na comhaid is ansa leat agus fillteáin.",
+    "Upload (max. %s)" : "Uaslódáil (%s ar a mhéad)",
+    "Submitting fields…" : "Réimsí á gcur isteach…",
+    "Filter filenames…" : "Scag ainmneacha comhaid…",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} fillteán","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} comhad","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 chomhad agus {folderCount} fillteán","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} comhad agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán"],
+    "{fileCount} files and {folderCount} folders" : "comhaid {fileCount} agus fillteáin {folderCount}",
     "Personal Files" : "Comhaid Phearsanta",
     "Text file" : "Comhad téacs",
     "New text file.txt" : "Comhad téacs nua.txt",
-    "Favored" : "B'fhearr leis",
-    "Favor" : "Fabhar",
-    "Not favored" : "Ní bail ar fónamh orthu",
-    "Submitting fields…" : "Réimsí á gcur isteach…",
-    "Filter filenames…" : "Scag ainmneacha comhaid…",
+    "%1$s (renamed)" : "%1$s (athainmnithe)",
+    "renamed file" : "comhad athainmnithe",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
     "{count} files could not be converted" : "{count} níorbh fhéidir comhaid a thiontú",
     "{count} files successfully converted" : "{count} comhaid a thiontú go rathúil"
 },
